@@ -11,15 +11,8 @@ Enhanced with SQLite3 JSON optimizations for 15-665x faster operations.
    Package exports
 """
 
+from .fields import ForeignKey, ManyToMany, RelatedSet
 from .kenobix import KenobiX
+from .odm import Document
 
-# ODM is optional - only import if cattrs is available
-try:
-    from .odm import Document
-
-    __all__ = ("Document", "KenobiX")
-except ImportError:
-    # cattrs not installed, ODM not available
-    __all__ = ("KenobiX",)
-
-__version__ = "5.0.0"
+__all__ = ("Document", "ForeignKey", "KenobiX", "ManyToMany", "RelatedSet")
